d <- read.csv("volcanoes.csv")
d$ACBR <- factor(d$ACBR)
d$Volcanic <- factor(d$Volcanic)
d$SiteID <- factor(d$SiteID)

pairs(~Ntaxa+GDD+Nrecords+Aicefree+Altitude,data=d)

boxplot(Ntaxa~ACBR,data=d)
stripchart(Ntaxa~ACBR,data=d,pch=16)



## Fit a simple glm with ACBR as a block
fit <- glm(Ntaxa ~ ACBR+log(Nrecords)+log(Aicefree)+GDD+Altitude+Volcanic,
		family=poisson(),data=d)
## Wildly overdispersed
summary(fit)

## Diagnostics look ok.
opar <- par(mfrow=c(2,2))
plot(fit)
par(opar)

## Check for proportionality
library(MASS)
confint(fit,"log(Nrecords)")
confint(fit,"log(Aicefree)")

## Partial residuals
opar <- par(mfrow=c(2,3))
termplot(fit,partial.resid=T)
par(opar)



## Quasi-poisson?
fit <- glm(Ntaxa ~ ACBR+log(Nrecords)+log(Aicefree)+Altitude+GDD+Volcanic,family=quasipoisson(),data=d)
summary(fit)

## Diagnostics are ok
opar <- par(mfrow=c(2,2))
plot(fit)
par(opar)




## Log transformed gaussian?
fit <- glm(log(Ntaxa) ~ ACBR+log(Nrecords)+log(Aicefree)+Altitude+GDD+Volcanic,family=gaussian(),data=d)
summary(fit)


## Equal variance but evidence of a residual trend?
opar <- par(mfrow=c(2,2))
plot(fit)
par(opar)


## Partial residuals
opar <- par(mfrow=c(2,3))
termplot(fit,partial.resid=T)
par(opar)



## Simple random effects
library(nlme)
fit <- lme(log(Ntaxa) ~ log(Nrecords)+log(Aicefree)+Altitude+GDD+Volcanic,random=~1|ACBR,data=d)
summary(fit)
anova(fit)

plot(fit)
qqnorm(fit,~residuals(.))
qqnorm(fit,~ranef(.))


library(nlme)
fit <- lme(log(Ntaxa) ~ log(Nrecords)+log(Aicefree)+Altitude+Volcanic,random=~1|ACBR,data=d)
summary(fit)
anova(fit)


## Penalized quasi-likelihood
library(MASS)
fit <- glmmPQL(Ntaxa ~ log(Nrecords)+log(Aicefree)+Altitude+GDD+Volcanic,random=~1|ACBR,family=poisson(),data=d)
summary(fit)
plot(fit)
qqnorm(residuals(fit))


library(lme4)
fit <- glmer(Ntaxa ~ log(Nrecords)+log(Aicefree)+Altitude+GDD+Volcanic+(1|ACBR),family=poisson(),nAGQ=4,data=d)
summary(fit)




